from setuptools import setup, find_packages

setup(
    name="myzippy",
    version="0.1",
    description="Highly scientific zipp measurement",
    author="Dr. Zipp",
    author_email="mailbot217@gmail.com",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
    ],
    python_requires='>=3.6',
)
